/****************************************************************************/
//
//  FlashPro-ARM Programmer - Multi-API-DLL software
//  Author: Gregory Czajkowski
//  Elprotronic Inc. 2003-2021
//  
/****************************************************************************/
// THIS PROGRAM IS PROVIDED "AS IS". ELPROTRONIC INC. MAKES NO WARRANTIES OR
// REPRESENTATIONS, EITHER EXPRESS, IMPLIED OR STATUTORY, 
// INCLUDING ANY IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS 
// FOR A PARTICULAR PURPOSE, LACK OF VIRUSES, ACCURACY OR 
// COMPLETENESS OF RESPONSES, RESULTS AND LACK OF NEGLIGENCE. 
// ELPROTRONIC INC. DISCLAIMS ANY WARRANTY OF TITLE, QUIET ENJOYMENT, QUIET 
// POSSESSION, AND NON-INFRINGEMENT OF ANY THIRD PARTY 
// INTELLECTUAL PROPERTY RIGHTS WITH REGARD TO THE PROGRAM OR 
// YOUR USE OF THE PROGRAM.
//
// IN NO EVENT SHALL ELPROTRONIC INC. BE LIABLE FOR ANY SPECIAL, INCIDENTAL, 
// CONSEQUENTIAL OR INDIRECT DAMAGES, HOWEVER CAUSED, ON ANY 
// THEORY OF LIABILITY AND WHETHER OR NOT ELPROTRONIC INC. HAS BEEN ADVISED 
// OF THE POSSIBILITY OF SUCH DAMAGES, ARISING IN ANY WAY OUT 
// OF THIS AGREEMENT, THE PROGRAM, OR YOUR USE OF THE PROGRAM. 
// EXCLUDED DAMAGES INCLUDE, BUT ARE NOT LIMITED TO, COST OF 
// REMOVAL OR REINSTALLATION, COMPUTER TIME, LABOR COSTS, LOSS 
// OF GOODWILL, LOSS OF PROFITS, LOSS OF SAVINGS, OR LOSS OF 
// USE OR INTERRUPTION OF BUSINESS. 
//
// Unless otherwise stated, the Program written and copyrighted 
// by Elprotronic Inc. is distributed as "freeware".  You may, 
// only under Elprotronic's Inc. copyright in the Program, use and modify the 
// Program without any charge or restriction.  You may 
// distribute to third parties, provided that you transfer a 
// copy of this license to the third party and the third party 
// agrees to these terms by its first use of the Program. You 
// must reproduce the copyright notice and any other legend of 
// ownership on each copy or partial copy, of the Program.
//
// You acknowledge and agree that the Program contains 
// copyrighted material, trade secrets and other Elprotronic Inc. proprietary 
// information and is protected by copyright laws, 
// international copyright treaties, and trade secret laws, as 
// well as other intellectual property laws.  To protect Elprotronic's Inc. 
// rights in the Program, you agree not to decompile, reverse 
// engineer, disassemble or otherwise translate any object code 
// versions of the Program to a human-readable form.  You agree 
// that in no event will you alter, remove or destroy any 
// copyright notice included in the Program.  Elprotronic Inc. reserves all 
// rights not specifically granted under this license. Except 
// as specifically provided herein, nothing in this agreement 
// shall be construed as conferring by implication, estoppel, 
// or otherwise, upon you, any license or other right under any 
// Elprotronic Inc. patents, copyrights or trade secrets.
//
/****************************************************************************/

#ifndef FLASHPRO_DLL_H
#define FLASHPRO_DLL_H

#ifndef __GNUC__
#define MSWIN_API		//comment out for Borland, DOS applications  etc if the CString is not supported

#ifdef  MSPPRG_DLL
   #define MSPPRG_API __declspec(dllexport)
#else
   #define MSPPRG_API __declspec(dllimport)
#endif //MSPPRG_DLL

#ifdef  MSWIN_API
  #define		CSTRING_EN
#endif //MSWIN_API

#else //__GNUC__
#define MSPPRG_API __attribute__ ((visibility("default")))
#define __stdcall  __attribute__ ((visibility("default")))
#endif //__GNUC__

typedef		int               INT_X;
typedef     unsigned short    UINT16;
typedef     unsigned int      UINT32;
typedef		unsigned char     BYTE;
typedef		char *			  BYTE_PTR;
typedef		void *			  VOID_PTR;

#define		REPORT_MESSAGE_MAX_SIZE		2000
#define		MAX_USB_DEV_NUMBER		64
#define		MAX_FPA_INDEX			64
#define		ALL_ACTIVE_FPA			0
#define		FPA_UNMATCHED_RESULTS		-1
#define		FPA_INVALID_NO			-2
#define		PRG_ADAPTER_NOT_DETECTED	4	

#define		INVALID_CODE_FILE		0x08
#define		CODE_OUT_OF_FLASH		0x40
#define		CODE_OVERWRITTEN		0x80

//====================================================================
//         Flash definition
//====================================================================

#define	FLASH_PASSW_LEN				8
#define	NO_OF_CSM_PASSWORDS			4

#define	CSM_DEFAULT_INDEX			0
#define	CSM_CODE_FILE_INDEX			1
#define	CSM_PASSWORD_FILE_INDEX		        2
#define	CSM_DEFINED_INDEX			3
#define	CSM_MAX_INDEX				CSM_DEFINED_INDEX

#define	RESET_10MS_INDEX            0
#define	RESET_50MS_INDEX			0	//not valid
#define	RESET_100MS_INDEX			1
#define	RESET_200MS_INDEX			2
#define	RESET_500MS_INDEX			3
#define	RESET_CUSTOM_INDEX			4
#define RESET_SOFT_INDEX			5
#define	RESET_MAX_INDEX				RESET_SOFT_INDEX

#define	APPLICATION_KEEP_RESET		0
#define	APPLICATION_TOGGLE_RESET	1
#define	APPLICATION_NOT_RESET		2
#define	APPLICATION_JTAG_RESET		3
#define	APPLICATION_TOGGLE_VCC		4
#define	APPLICATION_RESET_MAX_INDEX	APPLICATION_TOGGLE_VCC

#define	VERIFY_NONE_INDEX		0
#define	VERIFY_STD_INDEX		1
#define	VERIFY_FAST_INDEX		2
#define	VERIFY_MAX_INDEX		VERIFY_FAST_INDEX

#define	DEFAULT_JTAG_3ST		0
#define	DEFAULT_JTAG_HI			1
#define	DEFAULT_JTAG_LO			2
#define	MAX_DEFAULT_JTAG		DEFAULT_JTAG_LO

#define DEFAULT_RESET_LO		0
#define DEFAULT_RESET_HI		1
#define DEFAULT_RESET_3ST		2


// ===== Communication Inteface  =======
#define	COMM_TYPE_MASK		0xFFF8
#define	COMM_TYPE_SPEED		0x0003

#define	COMM_JTAG			0x0010
#define	COMM_cJTAG			0x0008
#define	COMM_SWD			0x0020
#define	COMM_ICSP			0x0020		//not used in ARM software

#define	COMM_BSL			0x0040
#define COMM_SBW			0x0080
#define	COMM_QSPI			0x0080	//the same as SBW - used in FP-M and GP-M
#define	COMM_SCI			0x0100//not supported a.t.m.
#define	COMM_UART			0x0200//not supported a.t.m.
#define	COMM_I2C			0x0400//not supported a.t.m.
#define	COMM_SWIM			0x0800
#define	COMM_SPI			0x1000
#define	COMM_TPI			0x2000
#define	COMM_PDI			0x4000
#define	COMM_UPDI			0x8000
#define	COMM_JTAG_PDI       ( COMM_PDI | COMM_JTAG )  //AVR- ATXMega
#define	COMM_MAX_INDEX		(COMM_UPDI | 7 )

#define	COMM_SLOW			0
#define	COMM_MEDIUM			1
#define	COMM_FAST			2

#define	COMM_JTAG_SLOW		(COMM_JTAG | COMM_SLOW)
#define	COMM_JTAG_MED		(COMM_JTAG | COMM_MEDIUM)
#define	COMM_JTAG_FAST		(COMM_JTAG | COMM_FAST)
#define	COMM_cJTAG_SLOW		(COMM_cJTAG | COMM_SLOW)
#define	COMM_cJTAG_MED		(COMM_cJTAG | COMM_MEDIUM)
#define	COMM_cJTAG_FAST		(COMM_cJTAG | COMM_FAST)
#define	COMM_SWD_SLOW		(COMM_SWD | COMM_SLOW) 
#define	COMM_SWD_MED		(COMM_SWD | COMM_MEDIUM) 
#define	COMM_SWD_FAST		(COMM_SWD | COMM_FAST)

#define	COMM_SPI_SLOW		(COMM_SPI | COMM_SLOW) 
#define	COMM_SPI_MED		(COMM_SPI | COMM_MEDIUM) 
#define	COMM_SPI_FAST		(COMM_SPI | COMM_FAST)
#define	COMM_QSPI_SLOW		(COMM_QSPI | COMM_SLOW) 
#define	COMM_QSPI_MED		(COMM_QSPI | COMM_MEDIUM) 
#define	COMM_QSPI_FAST		(COMM_QSPI | COMM_FAST)
#define	COMM_SWIM_FAST		(COMM_SWIM | COMM_FAST)
#define	COMM_SWIM_SLOW		(COMM_SWIM | COMM_SLOW)
#define	COMM_TPI_FAST		(COMM_TPI | COMM_FAST)
#define	COMM_TPI_MED		(COMM_TPI | COMM_MEDIUM)
#define	COMM_TPI_SLOW		(COMM_TPI | COMM_SLOW)
#define	COMM_PDI_FAST		(COMM_PDI | COMM_FAST)
#define	COMM_PDI_MED		(COMM_PDI | COMM_MEDIUM)
#define	COMM_PDI_SLOW		(COMM_PDI | COMM_SLOW)
#define	COMM_UPDI_FAST		(COMM_UPDI | COMM_FAST)
#define	COMM_UPDI_MED		(COMM_UPDI | COMM_MEDIUM)
#define	COMM_UPDI_SLOW		(COMM_UPDI | COMM_SLOW)
#define	COMM_ICSP_FAST		(COMM_ICSP | COMM_FAST)
#define	COMM_ICSP_MED		(COMM_ICSP | COMM_MEDIUM)
#define	COMM_ICSP_SLOW		(COMM_ICSP | COMM_SLOW)
#define COMM_UART_FAST		(COMM_UART | COMM_FAST)
#define COMM_UART_MED		(COMM_UART | COMM_MEDIUM)
#define COMM_UART_SLOW		(COMM_UART | COMM_SLOW)
#define	COMM_I2C_FAST		(COMM_I2C | COMM_FAST)
#define	COMM_I2C_MED		(COMM_I2C | COMM_MEDIUM)
#define	COMM_I2C_SLOW		(COMM_I2C | COMM_SLOW)

extern "C"
{
//Functions are described in more detail in DLL user guide, FP-ARM-API-DLL-User-Guide.pdf
//When selecting all FPAs, F_Set_FPA_index(0), any API-DLL function can also return:
//	FPA_UNMATCHED_RESULTS : Result of operation inconsistent across all selected FPAs, call F_LastStatus on single FPA
//  FPA_INVALID_NO : FPA not opened with F_OpenInstancesAndFPAs or index out of range
//This does not apply to Multi API-DLL calls.
	
//Call structure (Figure 1.2 FP-ARM-API-DLL-User-Guide.pdf):
//Multi API-DLL (FlashProARM-FPAsel.dll) (Multi-API DLL Functions)
//-(1) : API-DLL (FlashProARM-FPA1.dll)	(Generic, Data Buffer, Encapsulated, Sequential Functions)
//-(2) : API-DLL (FlashProARM-FPA2.dll)	(Generic, Data Buffer, Encapsulated, Sequential Functions)
//-(3) : API-DLL (FlashProARM-FPA3.dll)	(Generic, Data Buffer, Encapsulated, Sequential Functions)
//-(4) : API-DLL (FlashProARM-FPA4.dll)	(Generic, Data Buffer, Encapsulated, Sequential Functions)
//-(5) : API-DLL (FlashProARM-FPA5.dll)	(Generic, Data Buffer, Encapsulated, Sequential Functions)
//......
//-(64): API-DLL (FlashProARM-FPA64.dll)(Generic, Data Buffer, Encapsulated, Sequential Functions)
//F_Set_FPA_index(0) to send commands to all API-DLLs


	// ------------------  Multi-API DLL Functions ----------------------------
	/*
	These functions operate on meta-data within the Multi API-DLL and help manage the underlying API-DLL instances. 
	These functions do not directly program target devices. Use these functions to initialize the desired number of FPAs, 
	selected all or one FPA(s), read FPA serial numbers, or clean-up resources used by Elprotronic�s DLLs. Once the 
	desired FPAs have been successfully opened, use Generic Functions to initialize the FPAs, and con?gure them for 
	the target device(s) being programmed.
	*/	

	INT_X  MSPPRG_API	F_OpenInstancesAndFPAs( char * FileName );
	//  number of instances and FPA's assigment - vs FPA's Serial Number.
	//  FPAs configuration specified in the file "FileName" - full access path
	//  return   number of opened instances
	//
	//  Syntax of the FPAs configuration specified
	//  FPA-x   Serial Number
	//  where  FPA-x can be  FPA-1, FPA-2, FPA-3 ....
	//   e.g  (without semicolon  - comment)
	//  FPA-1   20050116
	//  FPA-3   20050199
	//  FPA-5   20050198
	//  return: number of opened instances

	INT_X  MSPPRG_API	F_CloseInstances( void );
	// Free API-DLLs from initialized FPAs
	// return:  1 - TRUE

	INT_X  MSPPRG_API	F_Set_FPA_index( BYTE fpa );
	// select fpa index. Set fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	
	// return:  1 - TRUE or Error number

	BYTE   MSPPRG_API	F_Get_FPA_index( void );
	// return:  current fpa index

	INT_X  MSPPRG_API	F_Check_FPA_index( void );
	// similar to F_Get_FPA_index(), but when the fpa is invalid then returns FPA_INVALID_NO
	// return:  current fpa index if selected FPA has been opened with F_OpenInstancesAndFPAs

        void   MSPPRG_API	F_Enable_FPA_index( BYTE fpa );
	// enable selected fpa index (default is enabled). Will be included in 
	// operations when fpa_index = ALL_ACTIVE_FPA, or if this fpa is selected
	// FPA - index no (1..MAX_FPA_INDEX)	

	void   MSPPRG_API	F_Disable_FPA_index( BYTE fpa );
	// disable selected fpa index.  Will be ignored for all operations
	// FPA - index no (1..MAX_FPA_INDEX)

	INT_X  MSPPRG_API	F_LastStatus( BYTE fpa );
	// Use this function to get single-fpa results when other functions return FPA_UNMATCHED_RESULTS
	// return last status taken from the selected fpa (fpa = 1..MAX_FPA_INDEX)	

	INT_X  MSPPRG_API	F_Multi_DLLTypeVer( void );
	// return	 Type + Version	
	//           Type	0x6000 - Multi-FPA FlashPro430
	//					0x7000 - Multi-FPA GangPro430
	//					0x8000 - Multi-FPA FlashPro-CC
	//					0x9000 - Multi-FPA GangPro-CC
	//					0xC000 - Multi-FPA FlashPro2000
	//					0xD000 - Multi-FPA GangPro2000
	//				   0x10000 - Multi-FPA FlashPro-ARM
	//				   0x11000 - Multi-FPA GangPro-ARM
	//				   0x17000 - Multi-FPA FlashPro-M
	//				   0x18000 - Multi-FPA GangPro-M
	//			 Version = 0x0FFF & version

	INT_X  MSPPRG_API	F_Get_FPA_SN( BYTE );
	//  return: 0 - Adapter not detected	
	//         >0 - Active Adapter's Serial Number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX

#define MAX_ID_DESC		 15
#define MAX_ACCESS_DESC	 32
	typedef struct
	{
		UINT32  active;
		UINT32  SN;
		UINT32  CommType;
		UINT32  HW_ID;
		UINT32  HW_rev;
		char  text[MAX_ID_DESC+1];
		char  access_text[MAX_ACCESS_DESC+1];
	} ALL_FPA_LIST;

	//i.e.: 
	//ALL_FPA_LIST FPA_List[MAX_USB_DEV_NUMBER];
	//F_Get_FPA_List(FPA_List);
	INT_X  MSPPRG_API	F_Get_FPA_List( ALL_FPA_LIST * FPA_List );	// FPA_List -> size MAX_USB_DEV_NUMBER

	INT_X  MSPPRG_API	F_Get_FPA_Label( BYTE fpa, BYTE * label );
	// fpa = 1....MAX_FPA_INDEX
	
	#define ADAPTER_HARDWARE_PN_SIZE		16	
	#define ADAPTER_DESCRIPTION_SIZE		32
	#define FPA_LABEL_SIZE					((ADAPTER_HARDWARE_PN_SIZE + ADAPTER_DESCRIPTION_SIZE)*sizeof(char) + 12*sizeof(BYTE) + sizeof(long))
	//union FPA_LABEL
	//{
	//	BYTE	bytes[ FPA_LABEL_SIZE ];
	//	struct
	//	{
	//		long  SN;
	//		BYTE  hardware_ID;
	//		BYTE  hardware_SubID;
	//		BYTE  full_access;
	//		BYTE  Interface_Type;
	//		BYTE  Valid_access_key;
	//		BYTE  spare3;
	//		BYTE  spare4;
	//		BYTE  spare5;
	//		BYTE  spare6;
	//		BYTE  spare7;
	//		BYTE  spare8;
	//		BYTE  spare9;
	//		char  adapter_hardware_PN[ ADAPTER_HARDWARE_PN_SIZE ];
	//		char  adapter_description[ ADAPTER_DESCRIPTION_SIZE ];
	//	}x;
	//};

	INT_X	MSPPRG_API F_Get_Power_Results(double *xs_adc);
		//execute power measurement and provide results
    #define	XS_ADC_NUM_MEMBERS 15
	/*union XS_ADC
	{
		double	members[ XS_ADC_NUM_MEMBERS ];
		struct
		{
			double ExtVcc;				//actual external Vcc value in V
			double Vcc;					//actual Vcc from programmer value in V
			double Vpp;					//actual Vpp for fuse blown from programmer value in V
			double ExtVccMin;			//external Vcc value in V - min value from the last read up to now
			double ExtVccMax;			//external Vcc value in V - max value from the last read up to now
			double VccMin;				//Vcc value in V - min value from the last read up to now
			double VccMax;				//Vcc value in V - max value from the last read up to now
			double Icc_mA;				//Icc value in mA - current value
			double Icc_mA_av4;			//Icc value in mA - average for last 4 read (interval ~ 10ms)
			double Icc_mA_av16;			//Icc value in mA - average for last 16 read (interval ~ 10ms)
			double Icc_mA_min;			//Icc value in mA - min value from the last read up to now
			double Icc_mA_max;			//Icc value in mA - max value from the last read up to now
			double Temperature;			//Temperature inside XStream in C deg
			double Icc_mA_av64;			//Icc value in mA - average for alpha 1/64
			double Icc_mA_av;			//Icc value in mA - average for defined alpha 1/N
		} data;
	};*/

	INT_X	MSPPRG_API F_Get_Last_Power_Results_data(double *xs_adc);
			//provide results taken from the last power measuremet (used function F_Get_Power_Results(double *xs_adc)) 

	//XStreamPro-Iso only
	INT_X	MSPPRG_API F_XS_Update_HW_State(BYTE mode, INT_X data);
#ifndef __IO_SETTINGS__
#define __IO_SETTINGS__
	// mode
	#define		MODE_XS_IO_SET_FLAGS		0x12
	#define		MODE_XS_IO_CLR_FLAGS		0x13
	// data
	#define     IO_PULLUP_EN				1
	#define     FORCE_ICC_LOW_SENSITIVITY	2
	#define     FORCE_ICC_HI_SENSITIVITY	4
#endif
	//example - disable I/O 1M pull-ups in 3-state 
	//		F_Update_HW_State( MODE_XS_IO_CLR_FLAGS, IO_PULLUP_EN );
	//example - Force current HI sensitivity range
	//		F_Update_HW_State( MODE_XS_IO_SET_FLAGS, FORCE_ICC_HI_SENSITIVITY );
	//		F_Update_HW_State( MODE_XS_IO_CLR_FLAGS, FORCE_ICC_LOW_SENSITIVITY );

	INT_X  MSPPRG_API   F_XS_Current_zeroing( int state, char *txt );
	// Example for calling function above
	// char txt[200];  //size must be 200 or more
	//  	for( state = 0; state < 100; state++)	//mandatory state from 0 to 100
	//      {  
	//	      F_XS_Current_zeroing( state, txt );
	//      } 
	//  - state can be used also as the progress bar 0..100
	//  txt - comment related to currently executing part of zeroing procedure - the same as it is displayed in GUI

	INT_X  MSPPRG_API	F_XS_Clr_ADC_av_history();
	// Deletes current measurement history, useful to get rid of long running averages.

	INT_X  MSPPRG_API	F_GetProgressBar( BYTE fpa );
	//Only for encapsulated functions
	//General function that only reads current value of progress bar between 0 and 100.  Thread-safe
	//One thread can call F_AutoProgram (for example) and another thread can monitor progress by calling
	//F_GetProgressBar
  
	INT_X  MSPPRG_API	F_GetLastOpCode( BYTE fpa );
	#define PROG_OPCODE_VERIFY_ACCESS				1
	#define	PROG_OPCODE_FLASH_ERASE					2
	#define	PROG_OPCODE_FLASH_BLANK_CHECK			3
	#define	PROG_OPCODE_FLASH_SELECTED_BLANK_CHECK	4
	#define PROG_OPCODE_FLASH_WRITE					5
	#define	PROG_OPCODE_FLASH_VERIFY				6
	#define	PROG_OPCODE_FLASH_READ					7
	#define	PROG_OPCODE_LOCK_MCU					8
	#define	PROG_OPCODE_UNLOCK_MCU					9
	#define	PROG_OPCODE_START_APP					10
	//Only for encapsulated functions
	//General function that reads code for last operation performed. Useful for providing comments for ProgressBar and 
	//when AutoProgram fails half way to indicate which sub-operation failed. Thread-safe
	//
	//One thread can call F_AutoProgram (for example) and another thread can monitor progress of sub-operations
	//by calling F_GetProgressBar and F_GetLastOpCode. F_AutoProgram will usually go through all of these sub-operations 
	//in seqeuence, each progressing from 0 to 100. If the blank-check sub-operation fails in F_AutoProgram, then this 
	//function will keep returning PROG_OPCODE_FLASH_BLANK_CHECK after F_AutoProgram returns FAIL.

	INT_X  MSPPRG_API	F_CancelAction( BYTE fpa );
	//Only for encapsulated functions
	//Function that will attempt to cancel all the running encapsulated functions, like the GUI Cancel button.  Thread-safe
	//One thread can call F_AutoProgram (for example) and another thread can call F_CancelAction to stop the first.
	//A reinitialization is recommended using F_OpenInstancesAndFPAs after calling this function.

	INT_X	MSPPRG_API	F_Trace_File( char *FileName, bool append = false );
	// set custom FileName for trace (used with Trace_ON).  Set append flag true to keep previous contents.
	// return:	0 - FALSE (failed to open file)
	//			1 - TRUE (opened file successfully)

	void   MSPPRG_API   F_Trace_Comment(char *comment);
	// append a custom comment to current trace file

	void	MSPPRG_API	F_Trace_ON( void );
	// enable trace: save names and parameters of functions called to DLLtrace.txt in current working directory

	void	MSPPRG_API	F_Trace_OFF( void );
	// disable trace
	
	// ------------------------------------------------------------------------

	// ------------------------  Generic Functions ----------------------------
	/*
	Generic functions read and write the API-DLL�s con?guration, access status messages and can instruct the FPA 
	to power or reset the target device. The functions described in this section require that each FPA already be 
	opened using F OpenInstancesAndFPAs.
	*/

	INT_X  MSPPRG_API	F_Initialization( void );
	// return:   0 - FALSE
	//           1 - TRUE
	//			 4 - Programmer adapter is not detected
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA		
	
	INT_X  MSPPRG_API	F_Use_Config_INI(BYTE use);
	//Configure F_Initialization to use (default) or skip config.ini file
	//	input 1 to use config.ini, input 0 to skip
	//when skipping config.ini it is necessary to use ConfigFileLoad or Set_Config_Value_By_Name functions to
	//configure the adapter.
	//	return		0 - FALSE (state unchanged)
	//				1 - TRUE (state changed to input parameter)
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA		

	//======================================================================================================//
	//Programmatically print and set configuration values from *.cfg file provided to F_ConfigFileLoad
	MSPPRG_API char *	F_Get_Config_Name_List( INT_X index );
	//Iterate over configuration names, starting from <index> 0.  Increase <index> until return is "\0".
	//Will return char array with name of config parameter or "\0" once <index> is too high.
  
	unsigned int MSPPRG_API F_Get_Config_Value_By_Name(char *name, INT_X type);
	//Use F_Get_Config_Name_List to get configuration parameter names, then use them as input 
	//to this function.  Select type to determine action:
	#define		CONFSEL_VALIDATE	0 //- returns TRUE if <name> was found in config list
	#define		CONFSEL_VALUE		1 //- returns current value of config parameter
	#define		CONFSEL_MIN			2 //- returns minimum value that this config parameter can have
	#define		CONFSEL_MAX			3 //- returns maximum value that this config parameter can have
	#define		CONFSEL_DEFAULT		4 //- returns default value for this parameter if not set by user/file
	//returns FALSE if invalid <name> given
  
	INT_X	MSPPRG_API	F_Set_Config_Value_By_Name(char *name, unsigned int newValue);
	//Use F_Get_Config_Name_List to get configuration parameter names, then use them as input 
	//to this function.  Use F_Get_Config_Value_By_Name to get proper ranges for config values.
	//
	//Set new value for configuration parameter identified by <name>.
	//If the config parameter is out of range, it will be reset to default value.
	//Returns TRUE if <name> was valid, or FALSE if <name> was invalid
	//Run F_Get_Config_Value_By_Name(<name>, CONFSEL_VALUE) after to verify change of configuration parameter.

	//======================================================================================================//
	//Get setup config string name list for string parameters
	MSPPRG_API char* F_Get_String_Config_Name_List(int index);

	//Get current setup configuration for string parameters - could be read from file, or read from software configuration
	MSPPRG_API char * F_Get_String_Config_Value_By_Name(char *name, int type);
	//Use F_Get_String_Config_Name_List to get configuration parameter names, then use them as input 
	//to this function.  Select type to determine action:
	//#define		CONFSEL_VALIDATE	0 //- returns parameter name if <name> was found in config list
	//#define		CONFSEL_VALUE		1 //- returns current value of config parameter
	//#define		CONFSEL_DEFAULT		4 //- returns default value for this parameter if not set by user/file
	//returns FALSE if invalid <name> given

	//Set setup configuration by software
	int MSPPRG_API F_Set_String_Config_Value_By_Name(char *name, char *newValue);
	//======================================================================================================//
	
	INT_X  MSPPRG_API	F_Get_Device_Info( INT_X index );
	//where index
	#define	DEVICE_NAME						0
	#define	DEVICE_NAME_SIZE				20
	#define	DEVICE_FAMILY_INDEX				20
	#define	DEVICE_GROUP_INDEX				21
	#define	DEVICE_NAME_INDEX				22
	#define	DEVICE_GROUP					23
	#define	DEVICE_FLASH_START_ADDR			24
	#define	DEVICE_FLASH_END_ADDR			25
	#define	DEVICE_OTP_START_ADDR			26
	#define	DEVICE_OTP_END_ADDR				27
	#define	DEVICE_RAM_START_ADDR			28
	#define	DEVICE_RAM_END_ADDR				29
	#define DEVICE_VENDOR_INDEX				30
	#define	DEVICE_EEPROM_START_ADDR		31
	#define	DEVICE_EEPROM_END_ADDR			32
	#define	DEVICE_COMM_INTERFACES			33
	#define DEVICE_EXTFLASH_START_ADDR		34
	#define DEVICE_EXTFLASH_END_ADDR		35
	//  fpa = 1....MAX_FPA_INDEX
	//  return  -1 if invalid data
	//   or	
	//	  index - 0 to 19  -> device name - char by char starting from index->0 => T eg.  TMS320F2808   
	// 	     index 0 -> 'L'
	// 	     index 1 -> 'M'
	// 	     index 2 -> '4'   LM4F110B2QR
	// 	     index 3 -> 'F'
	// 	     index 4 -> '1'
	// 	     index 5 -> '1'
	// 	     index 6 -> '0'
	// 	     index 7 -> 'B'
	// 	     index 8 -> '2'
	// 	     index 9 -> 'Q'
	// 	     index 10 -> 'R'
	// 	     index 11 -> 0x0000  -> end of string
	//	  index 20 -> Family Index (subset of MCU vendor, index 30)
	//	  index 21 -> Group Index (subset of MCU family, index 20)
	//	  index 22 -> Name Index (subset of MCU group, index 21)
	//    index 23 -> Group (obsolete)
	// 	  index 24 -> Flash Start Address  eg 0x00000
	// 	  index 25 -> Flash End  Address   eg 0x1FFFF
	// 	  index 26 -> OTP Start Address    eg 0x400FE1E0
	// 	  index 27 -> OTP End  Address     eg 0x400FE1EF
	// 	  index 28 -> RAM Start Address    eg 0x20000000
	// 	  index 29 -> RAM End Address      eg 0x2000FFFF
	// 	  index 30 -> Vendor Index (superset of all supported MCUs, i.e. company name)
	// 	  index 31 -> EEPROM Start Address  eg 0x08080000
	// 	  index 32 -> EEPROM End Address    eg 0x080803FF
	// 	  index 33 -> MCU communication interfaces eg 0x30 ( COMM_JTAG | COMM_SWD )
	//	  index 34 -> External Flash Start Address  eg 0x10000000
	//	  index 35 -> External Flash End Address    eg 0x1001FFFF

	INT_X  MSPPRG_API	F_Set_MCU_Name( char * MCU_name );
	//  return:  -1 - not found,  X - MCU index if MCU_name was found
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	MSPPRG_API	void* F_Search_MCU_Name( char *MCU_name_regex, char *Vendor_filter, int mode, int flags );
	// MCU_name_regex - regular expression
	/*
	*   '.'        Dot, matches any character
	*   '^'        Start anchor, matches beginning of string
	*   '$'        End anchor, matches end of string
	*   '*'        Asterisk, match zero or more (greedy)
	*   '+'        Plus, match one or more (greedy)
	*   '?'        Question, match zero or one (non-greedy)
	*   '[abc]'    Character class, match if one of {'a', 'b', 'c'}
	*   '[a-zA-Z]' Character ranges, the character set of the ranges { a-z | A-Z }
	*   '\s'       Whitespace, \t \f \r \n \v and spaces
	*   '\S'       Non-whitespace
	*   '\w'       Alphanumeric, [a-zA-Z0-9_]
	*   '\W'       Non-alphanumeric
	*   '\d'       Digits, [0-9]
	*   '\D'       Non-digits
	*/
	//Vendor_filter - Limit to one vendor only, to speed up search function esp in mode with more than first match result.
	/*
	* NULL all enabled lists on this adapter
	* "Active-Semi"
	* "Analog Devices"
	* "Cypress"
	* "Microchip/Atmel"
	* "Marvell Tech."
	* "Maxim Integrated"
	* "Nordic Semiconductor"
	* "NXP/Freescale"
	* "Renesas"
	* "Silergy"
	* "Silicon Labs"
	* "ST Microelectronics"
	* "Texas Instruments-ARM"
	* "Texas Instruments-Chipcon"
	*/
	// mode: 
	//  mode 0, returns the first match to MCU_name_regex, a type (char *). Library will alloc and free this memory by itself, do not modify contents
	//  mode 1, returns the pointer to a list of matches to MCU_name_regex, a type (char **). Library will alloc and free this memory by itself, do not modify contents
	// flags: 
	//	for mode 0, not used
	//	for mode 1, max number of results to return, unlimited if 0
	//  return:  NULL if no match, 
	//  more regex modes TBA...
	//  You can use a valid MCU_name output of this function to call F_Set_MCU_Name
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX, 0 will return NULL	

	void  MSPPRG_API	F_Reset_Config();
	//reset all configuration values to default for selected MCU.

/******** Use these two functions together to get all supported MCU names *********/
	//Detailed example in DLL functions chapter, section F_Set_MCU_Family_Group (FP-ARM-API-DLL-User-Guide.pdf)
	MSPPRG_API	char *  F_Get_MCU_Name_list( INT_X type, INT_X index );
	#define		MCU_VENDOR_LIST		0
	#define		MCU_FAMILY_LIST		1
	#define		MCU_GROUP_LIST		2
	#define		MCU_NAME_LIST		3
	// return: valid name if correct parameters provided, "" otherwise
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX

	INT_X  MSPPRG_API	F_Set_MCU_Family_Group( INT_X type, INT_X index );
	//#define		MCU_VENDOR_LIST		0
	//#define		MCU_FAMILY_LIST		1
	//#define		MCU_GROUP_LIST		2
	//#define		MCU_NAME_LIST		3
	// return: 0 - index parameter out of range
	//		   1 - index parameter set correctly	
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX
/******** Use the above two functions to get all supported MCU names **************/

	void	 MSPPRG_API	F_ReportMessage( char * text );
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX

	MSPPRG_API	char* F_Report_Message( void );
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX

	BYTE   MSPPRG_API	F_GetReportMessageChar( INT_X index );
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX

	INT_X  MSPPRG_API	F_DLLTypeVer( void );
	// return	 Type + Version	
	//           Type   0x1000 - Single FlashPro430 - Parallel Port type  
	//					0x2000 - Single FlashPro430 - USB type  
	//					0x3000 - Single GangPro430  - USB type  
	//					0x4000 - Single FlashPro-CC - USB type  
	//					0x5000 - Single GangPro-CC  - USB type  
	//					0xA000 - Single FlashPro2000- USB type  
	//					0xB000 - Single GangPro2000 - USB type  
	//					0xE000 - Single FlashPro-ARM - USB type  
	//					0xF000 - Single GangPro-ARM - USB type  
	//			 Version = 0x0FFF & version
	// extra message in the report buffer 		

	INT_X  MSPPRG_API	F_ConfigFileLoad( char * filename );
	// filename - full name including path, file name and extension
	//  return:  0 - FALSE,  1 - TRUE or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_LoadFromImage(char * fullPath, char *password);
	// fullPath - fullPath including path, file name and extension of *.eimg
	// password - "" or password (up to 16 chars) if image is password locked
	//  return:  0 - FALSE,  1 - TRUE or Error number

	INT_X	 MSPPRG_API	F_Power_Target( INT_X OnOff );
	//  return:  0 - FALSE,  1 - TRUE
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	
	
	INT_X  MSPPRG_API	F_Reset_Target( void );
	// Hard reset
	//  return:  0 - FALSE,  1 - TRUE
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Get_Targets_Vcc( void );
	//  return   -1 - no communication with FPA
	//	return   0 and up - Vcc in milivolts
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X	 MSPPRG_API	F_Set_fpa_io_state( BYTE jtag, BYTE reset, BYTE VccOn );
	//  jtag ->  TMS, TCK, TDI (output from FPA)
	//          DEFAULT_JTAG_3ST   ( 0 )
	//			DEFAULT_JTAG_HI	   ( 1 )
	//			DEFAULT_JTAG_LO    ( 2 )
	// reset -> DEFAULT_RESET_LO    ( 0 )
	//			DEFAULT_RESET_HI	( 1 )
	//			DEFAULT_RESET_3ST   ( 2 )
	// VccOn ->  0  -> output Vcc from FPA - OFF
	//			 1  -> output Vcc from FPA - ON (level 2.2V to 3.6V set in CFG_VCCINDEX )
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Get_Sector_Size( INT_X address );
	//returns <sector size> for sector that includes given address
	//returns 0 for incorrect addresses (address that does not fit within any sector)
	//  return: 0 - address out of range, X - actual sector size
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	// ------------------------------------------------------------------------

	// ------------------------  Data Buffer Functions ----------------------------
	/*
	Use the functions in this section to specify what code should be written by each FPA to their target device. 
	All data buffers are enumerated and explained in detail in the user guide (FP-ARM-API-DLL-User-Guide.pdf)
	*/

	INT_X  MSPPRG_API	F_ReadCodeFile( char * FileName );	
	// Input is the first code file to be read.  
	// FileName - full name including path, file name and extension	
	// This function will reset all code buffer contents before it reads the 
	// selected file (will clear appended files)
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	
	INT_X  MSPPRG_API	F_ReadCodeFile_BaseAddr( char * FileName, UINT32 baseAddr );
	// Same as F_ReadCodeFile, but adds baseAddr to all data, useful for reading binary files

	INT_X  MSPPRG_API	F_AppendCodeFile( char * FileName );
	// Append code file contents to existing code buffer.  Up to 20 files in total
	//  return: 1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA		
	INT_X  MSPPRG_API	F_AppendCodeFile_BaseAddr( char * FileName, UINT32 baseAddr );
	// Same as F_AppendCodeFile, but adds baseAddr to all data, useful for reading binary files
	
	INT_X  MSPPRG_API	F_Get_CodeCS( INT_X dest );
	//  return: 0 - FALSE,  X - checksum of selected buffer, dest:
	//1: code from internal Code Buffer
	//2: code used in last F_AutoProgram or F_Memory_Write operation.
	//3: flash memory read after last F_AutoProgram or F_Memory_Verify operation.
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Clr_Code_Buffer( void  );
	// Clear Code Buffer (Figure 1.2, FP-ARM-API-DLL-User-Guide.pdf)
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Put_Byte_to_Code_Buffer( INT_X  addr, BYTE data );
	// Write byte to Code Buffer (Figure 1.2, FP-ARM-API-DLL-User-Guide.pdf)
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Get_Byte_from_Code_Buffer( INT_X  addr );
	// Read byte from Code Buffer (Figure 1.2, FP-ARM-API-DLL-User-Guide.pdf)
	//  return: 0 to 0xFF - byte from buffer,  -1 - addr parameter out of flash range
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Put_Byte_to_Buffer( INT_X  addr, BYTE data );	
	// Write byte to temporary Write Buffer (Figure 1.2, FP-ARM-API-DLL-User-Guide.pdf)
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA

	INT_X  MSPPRG_API	F_Get_Byte_from_Buffer( INT_X  addr );
	// Read byte from temporary Read Buffer (Figure 1.2, FP-ARM-API-DLL-User-Guide.pdf)
	//  return: 0 to 0xFF - byte from buffer,  -1 - addr parameter out of range
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA

    // ------------------------------------------------------------------------

	// ------------------------  Encapsulated Functions -----------------------
	/*
	These functions perform all device actions from beginning to end automatically. These functions require
	that all FPAs were opened using Multi API-DLL function F_OpenInstancesAndFPAs and each API-DLL instance 
	was correctly initialized using Generic Functions.  If not already included in configuration settings, 
	the code being programmed by each FPA to its target device can be set using Data Buffer Functions

	Encapsulated functions use the following sequence:
		- FPA opens target device according to configuration settings,
		- FPA establishes communicatino with target device (JTAG/SWD), check ID, calibrates clock,
		- FPA performs selected encapsulated function,
		- FPA terminates communication with target device,
		- FPA closes target device according to configuration settings (power, start app, adapter line states, etc.)
	*/

	INT_X  MSPPRG_API	F_AutoProgram( INT_X mode = 0 );// mode -> 0 value 1..up  reserved
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Verify_Access_to_MCU( void );
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Memory_Erase( INT_X mode = 0 );
	//mode-> 0 -> erase space specify by the FlashEraseModeIndex;
	//mode-> 1 -> erase all Flash memory, regardless FlashEraseModeIndex;
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Memory_Blank_Check( void );
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Memory_Write( INT_X mode = 0 );// mode -> 0   value 1..up  reserved
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Memory_Verify( INT_X mode = 0 );// mode -> 0   value 1..up  reserved
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Memory_Read( void );	
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	
	
	INT_X  MSPPRG_API	F_Lock_MCU( void );
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API F_Clear_Locked_Device( void );
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	// ------------------------------------------------------------------------

	// ---------------------  Sequential Functions ----------------------------
	/*
	Sequential functions allow access to the target device in any
	combination of the small instructions like erase, read, write sector,
	modify part of memory etc. 

	F_OpenInstancesAndFPAs
	F_Set_FPA_index
	F_Initialization
	F_ConfigFileLoad
	F_Open_Target_Device
	... < sequential functions here > ...
	F_Close_Target_Device
	*/

	INT_X  MSPPRG_API	F_Open_Target_Device( void );
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Close_Target_Device( void );
	//  return: 0 - not executed,  1 - executed  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Segment_Erase( INT_X  address );
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	
	
	INT_X  MSPPRG_API	F_Sectors_Blank_Check( INT_X  start_addr, INT_X  stop_addr );
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Copy_Buffer_to_Flash( INT_X  start_addr, INT_X  size );
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Copy_Flash_to_Buffer( INT_X  start_addr, INT_X  size );
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Write_Byte_to_RAM( INT_X  addr, BYTE data );
	// write byte to any location of RAM, registers etc. Write to flash space will fail
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Write_Word16_to_RAM( INT_X  addr, INT_X data );
	// write word to any location of RAM, registers etc. Write to flash space will fail
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Write_Word32_to_RAM( INT_X  addr, INT_X data );
	// write dword to any location of RAM, registers etc. Write to flash space will fail
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Write_Bytes_Block_to_RAM( INT_X start_addr, INT_X size, BYTE *data );
	// write byte array to any location of RAM, registers etc. Write to flash space will fail
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	
	
	INT_X  MSPPRG_API	F_Read_Byte( INT_X  addr );
	// read byte from any location of memory, registers etc.
	//  return: 0 to 0xFF  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Read_Word16( INT_X  addr );
	// read word from any location of memory, registers etc.
	//  return: 0 to 0xFFFF  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Read_Word32( INT_X  addr );
	// read dword from any location of memory, registers etc.
	//  return: 0 to 0xFFFFFFFF  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Read_Bytes_Block( INT_X start_addr, INT_X size, BYTE *data );	
	// read bytes from any location of memory, registers etc.
	//  return: read results in data buffer
	//  return: 0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX

	INT_X  MSPPRG_API	F_Set_PC_and_RUN( INT_X  PC_addr );
    //  return:  0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Write_Locking_Registers( void );
	//  return:  0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API	F_Write_Debug_Register( void );
	//  return:  0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	#define	GET_MCU_ID			1//MCU package identifier (MCU family and group, etc.), not a unique silicon ID
	#define	GET_MCU_FLASH_SIZE	2
	#define GET_MCU_RAM_SIZE	3
	INT_X  MSPPRG_API	F_Get_MCU_Data( INT_X Type = GET_MCU_ID );	
	//Not all MCUs contain Flash size/RAM size in ID register
	//  return: MCU Data if result is positive ( >= 0) 
	//  return:  0 - FALSE,  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	INT_X  MSPPRG_API F_Capture_PC_Addr();
	//read program counter (PC) register using debug interface
	//  return: PC if result is positive ( >= 0) 
	//  return:  0 - FALSE,  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	
	
	INT_X  MSPPRG_API F_Synch_CPU_JTAG();
	//stop CPU (debug enable and halt)		
	//  return:  0 - FALSE,  1 - TRUE  or Error number
	//  F_Set_FPA_index fpa = 1....MAX_FPA_INDEX  or  0 -> ALL_ACTIVE_FPA	

	// ---------------------  Debugging Functions ----------------------------
	// All debugging functions require specific FPA index; F_Set_FPA_index fpa = 1....MAX_FPA_INDEX
	INT_X   MSPPRG_API  F_Open_Comm(UINT32 activeReset);
	//Open debug communication
	// return: 0 - FALSE (failed), 1 - TRUE
	// activeReset - keep MCU in reset during initialization	

	INT_X	MSPPRG_API	F_Enable_Debug(void);
	//Enable debugging mode 
	//  return: 0 - FALSE (no communication), 1 - TRUE, write executed

	INT_X	MSPPRG_API	F_Enable_Debug_Halt(void);
	//Enable debugging mode and halt the core
	//  return: 0 - FALSE (no communication), 1 - TRUE, write executed

	INT_X	MSPPRG_API	F_Disable_Debug(bool interruptsDisabled);
	//Disable debugging mode, optionally set C_MASKINTS
	//  return: 0 - FALSE (no communication), 1 - TRUE, write executed
	//  set interruptsDisabled true to set C_MASKINTS. 		


	INT_X   MSPPRG_API	F_Step(bool interruptsDisabled);
	//Step the processor
	//  return: 0 - FALSE (no communication), 1 - TRUE, write executed
	//  set interruptsDisabled true to set C_MASKINTS. 

	INT_X	MSPPRG_API	F_Check_If_Cpu_Is_Halted(void);
	//Reads halt flag from debug status register
	//  return: 0 - FALSE (no), 1 - TRUE (yes)

	//INT_X  MSPPRG_API	F_Reset_Target( void );hard reset implemented above
	INT_X  MSPPRG_API	F_Soft_Reset_Target(void);
	//Software reset (system reset request AIRCR)
	//  return: 0 - FALSE (no communication), 1 - TRUE, write executed

	INT_X  MSPPRG_API	F_ReadCoreRegister( UINT32 regIndex, UINT32 *regValue );
	//Read core register using debug interface
	//  return: 0 - FALSE if invalid register index (unsupported) or no communication, 1 - TRUE if register read, 
	//  regIndex - core register index, 
	//  regValue - register value if read;

	INT_X  MSPPRG_API	F_WriteCoreRegister( UINT32 regIndex, UINT32 regValue );
	//Write core register using debug interface
	//  return: 0 - FALSE if invalid register index (unsupported) or no communication, 1 - TRUE if register read, 
	//  regIndex - core register index, 
	//  regValue - value to write to reg. 	

	
	INT_X  MSPPRG_API	F_ReadManyCoreRegisters( UINT32 *regIList, UINT32 *regValue, INT_X size );
	//Read core registers using debug interface
	//	return: 0 - FALSE if invalid register indices or no communication, 1 - TRUE if registers read,
	//  regIList - list of register indices to read, 	
	//  regValue - list of register values read,
	//  size - list size
	
	INT_X  MSPPRG_API	F_WriteManyCoreRegisters( UINT32 *regIList, UINT32 *regValue, INT_X size );
	//Write core registers using debug interface
	//	return: 0 - FALSE if invalid register indices or no communication, 1 - TRUE if registers written,
	//  regIList - list of register indices to write, 	
	//  regValue - list of register values to write,
	//  size - list size

	INT_X  MSPPRG_API	F_SetBoot0(INT_X BOOT0_override, INT_X BOOT0_value);
	//Override nTRST pin for BOOT0 control in some MCUs.
	//BOOT0_override == TRUE, force BOOT0_value on nTRST pin, BOOT0_override == FALSE, return to normal nTRST control (default FALSE)
	//BOOT_value, 1/0

	//start UART service functions - XStream and XStreamPro
	INT_X  MSPPRG_API	F_Open_UART( int BR_bps, int Parity_ON, int No_of_Stops );
	//Configure UART connection inside adapter
	//  return: 0 - FALSE (no communication to adapter), 1 - TRUE, parameters set
	// Parity_ON - parity bit, enable-1 or disable-0
	// No_of_Stops - number of stop bits 1 or 2
	// BR_bps - Baud Rate, bits per second, any 3kb/s to 1Mb/s  i.e. 9600, 15000, 115200, 921600, etc.
	// note:
	//   for BR_bps > 41500
	//		BR_div = (int)(0.5 + 168.0 * 10^6 / 3.0 / BR_bps);
	//		BR_real_bps = 168.0 * 10^6 / 3.0 / BR_div;
	//   for BR_bps <= 41500
	//		BR_div = (int)(0.5 + 12.0 * 10^6 / 3.0 / BR_bps);
	//		BR_real_bps = 12.0 * 10^6 / 3.0 / BR_div;
	//	 BR_error [%] = 100 * (BR_real_bps - BR_bps)/BR_bps;
	//   For example:
	//      BR_bps = 600000, then BR_div = 93,  BR_real_bps = 602150, BR_error [%] = +0.36%
	//      BR_bps =  38400, then BR_div = 104, BR_real_bps =  38461, BR_error [%] = +0.16%

	
	INT_X  MSPPRG_API	F_Close_UART();
	//Close UART connection
	//  return: 0 - FALSE (no communication to adapter), 1 - TRUE, UART turned off inside adapter

	INT_X  MSPPRG_API	F_TxRx_data_via_UART( int TxSize, int RxSize, int timeout_ms, BYTE * TxData, BYTE * RxData );
	//  return:
	//  flags mask   - 0xC000
	//                 0x8000 - finished OK
	//                 0x4000 - Rx timeout	- if set - received 0 or less bytes that requested
	//  Rx Size mask - 0x0FFF -> no of received Rx bytes. If flag is not 0x4000, then received all bytes as requested.
	//     for example - response 0x8002 - received OK 2 bytes as requested. If more bytes that requested, then extra bytes are ignored.
	//				    	
	// TxSize - number of bytes in TxData to be sent
	// RxSize - number of bytes to be received, RxData must contain enough space to write into it
	// timeout_ms - timeout in ms to wait for RxData
	// TxData - buffer with bytes to be sent
	// RxData - buffer that received bytes will be written into (should be preallcoated by caller)

	//end UART service functions - XStream and XStreamPro
	
// --- Standalone functions - used in XStreamPro-Iso only ------

#define	IMAGE_HEADER_SIZE		0x100
#define	IMAGE_QUOTA_LOG_SIZE	0x10
#define	SCRIPT_TEXT_SIZE		12
#define	SCRIPT_MCU_NAME_SIZE	16
#define	YEAR_SHIFT		25
#define	MONTH_SHIFT		21
#define	DAY_SHIFT		16
#define	HOUR_SHIFT		11
#define	MIN_SHIFT		5
#define	SEC_SHIFT		1
#define	ERR_IMAGE_HEADER_PSA_ERR	2120
#define	ERR_IMAGE_HEADER_EMPTY		2121
#define	ERR_IMAGE_HEADER_ID_ERR		2122


typedef union           //header not encrypted
{
  BYTE		bytes[IMAGE_HEADER_SIZE+IMAGE_QUOTA_LOG_SIZE];  
  UINT16	w16[(IMAGE_HEADER_SIZE+IMAGE_QUOTA_LOG_SIZE)/2];  
  UINT32	w32[(IMAGE_HEADER_SIZE+IMAGE_QUOTA_LOG_SIZE)/4];    

  struct
  {
	UINT32	own_PSA;                //0      
	UINT32	HeaderID_L;             //4        fixed - 0x13579BDF 
	UINT32	HeaderID_H;             //8        fixed - 0xECA86420      
	UINT32	global_PSA;             //12    
#define GLOBAL_PSA_START_OFFSET	        16        
	UINT32	image_FW_offset;        //16    //space encrypted     
	UINT32	image_data_offset;		//20	//space encrypted  
	UINT32	M0M4_FW_offset;			//24	//space encrypted  
	UINT32	image_SN_offset;        //28    //space not encrypted      
#define VERIFY_START_OFFSET				32        
    UINT32	image_size;             //32   
    UINT16	M0_FW_size;             //36
	UINT16	M4_FW_size;             //38   
    UINT16	M4_SW_ID;               //40         
    UINT16	M4_SW_ver;              //42                  
    UINT16	M0_SW_ver;              //44                  
    UINT16	C_SW_ver;               //46                         
    UINT16	Limit_qty;              //48                                  
    UINT16	Limit_seq_no;           //50                                          
	UINT32  date;					//52
	UINT16	terminate_task_no;      //56       
    UINT16	FPA_access_ID[8];       //58
	char	comment[SCRIPT_TEXT_SIZE]; //74
	UINT16	chunks;                 //86
	UINT32	FPA_SN;                 //88                                      
	UINT16	used_tasks_mask;		//92                
	UINT16	spare1;					//94
	UINT16	Vcc_mV;					//96	
	UINT16	min_Vcc_mV;				//98
	UINT16	max_Vcc_mV;				//100
	UINT16	RST_time_ms;			//102
	UINT16	RST_release_ms;			//104
	UINT16	Interface;				//106   type (JTAG, SBW, BSL), speed(Fast, Med, Slow) 
    UINT16  flags;					//108        
	BYTE	Icc_limit_mA;			//110
    BYTE    Erase_En;				//111
    BYTE    Erase_En_mask;          //112
	BYTE	SecureDev_En;			//113
    BYTE    IO_cfg;					//114
    BYTE    chain_IR_head;		    //115
    BYTE    chain_IR_tail;          //116
    BYTE    chain_DR_head;          //117
    BYTE    chain_DR_tail; 		    //118
	BYTE	Vcc_PowerEn;			//119

	BYTE    JTAG_unlockEn	        : 1;    //120
	BYTE    HasLockedInfoA          : 1;    //120
	BYTE    HasAutoEraseInBSL       : 1;    //120
	BYTE    BSL_X_type				: 1;    //120
	BYTE    SBW_via_RST  	        : 1;    //120
	BYTE    GreenLongButton			: 2;    //120
	BYTE    spare_flag7				: 1;    //120

	BYTE    SA_log_enable	        : 1;    //121
	BYTE    init_with_active_reset  : 1;    //121
	BYTE    SkipEraseIfBlank        : 1;    //121
	BYTE    SA_spare_3				: 1;    //121
	BYTE    SA_spare_4 				: 1;    //121
	BYTE    SA_spare_5				: 1;    //121
	BYTE    SA_spare_6				: 1;    //121
	BYTE    SA_spare_7				: 1;    //121

 //	BYTE		free[128-122];
  }prg;


  struct
  {
	BYTE 	offset[IMAGE_HEADER_SIZE/2];

	char	MCU_name[SCRIPT_MCU_NAME_SIZE];		//0
	UINT32	Id[4];					//16
	UINT32  SubId[4];				//32
    UINT32  flags;                  //48        
    UINT32	RAM_addr;				//52
    UINT32	RAM_size;				//56        
    UINT32	SubIDAddr;				//60                
    UINT16	CPU_max_freq;			//64 
    UINT16	WR_data_buf_size;		//66         
	BYTE	fast_init			: 1;   //68        
	BYTE	set_PSR				: 1;   //68        
	BYTE	has_SBW				: 1;   //68        
	BYTE	has_JTAG			: 1;   //68        
	BYTE	has_BSL				: 1;   //68        
	BYTE	has_CC_ICEPick		: 1;   //68        
	BYTE	multiple_ids		: 1;   //68        
	BYTE	F7_free				: 1;   //68        
    BYTE    CORE_type;              //69
    BYTE    FlashType;              //70
    BYTE    SegmentSize;            //71
	BYTE    PrgSpeedCoeff;			//72
	BYTE    SYS_Clk;				//73
	BYTE    MCU_type;				//74

	BYTE        DefaultDCO          : 1;	//75		
    BYTE        ASIC                : 1;	//75		
	BYTE        has_MPU             : 1;	//75		        
    BYTE        JTAG_Passw          : 1;	//75		
    BYTE        BSLprogrammable     : 1;	//75		
    BYTE        JTAG_Unlockable     : 1;	//75		
    BYTE        BSL_16B_passw       : 1;	//75		
    BYTE        has_MPU_IPE         : 1;	//75		

	BYTE		Quick_W				: 1;	//76
	BYTE		Quick_R				: 1;	//76
	BYTE		Quick_W_bug			: 1;	//76
	BYTE		Quick_WclkA			: 1;	//76
	BYTE		BSL_F5x_StdEntry    : 1;	//76
	BYTE		BSL9600	        	: 1;	//76
	BYTE		FRAM_directWr_En	: 1;	//76
	BYTE		AutoBlankCheckDis	: 1;	//76

	BYTE		FastFlash;				//77

    UINT16		Vendor;		        //78        
    UINT16		Family;		        //80                
    UINT16		Group;		        //82
    UINT16		FeatureBA;			//84
    UINT16		FeatureBB;			//86        
	UINT16		Map_index;			//88        	
 //	free 128-78;        
  }device;
  struct
  {
	BYTE 		offset[IMAGE_HEADER_SIZE];
	UINT16		err_no;
		#define  ERR_LOG_REACH_LIMIT     3007
	UINT16		ctr_no;
	UINT16		LastCtrNo;
	//..free
  }quota;
} IMAGE_HEADER;

	INT_X  MSPPRG_API	F_GetImageHeader( BYTE *data );		//data size - 0x100
	//  return: 0 - FALSE (no communication or no XStreamPro-Iso), 1 - TRUE
	INT_X  MSPPRG_API	F_SetImageNumber( INT_X dest, INT_X ImageNo );
	#define	 TMP_IMAGE_NO			1
	#define	 LOG_IMAGE_NO			2
	#define	 STANDALONE_IMAGE_NO	3
	//  return: 0 - FALSE (no communication or no XStreamPro-Iso), 1 - TRUE
	INT_X  MSPPRG_API	F_GetImageNumber( INT_X *ImageNo );
	//  return: 0 - FALSE (no communication or no XStreamPro-Iso), 1 - TRUE
	INT_X  MSPPRG_API	F_SetStandaloneFunction( INT_X cmd );
	#define	 STANDALONE_CMD_TERMINATE		0
	#define	 STANDALONE_CMD_AUTOPROGRAM		1
	#define	 STANDALONE_CMD_VERIFY			2
	#define	 STANDALONE_CMD_ERASE			3
	#define	 STANDALONE_CMD_UPDATE_REPORT	0x10
	#define	 STANDALONE_CMD_IS_DONE			0x11
		#define   TC_TERMINATED             0xFC
		#define   TC_WITH_ERROR             0xFD
		#define   TC_DONE                   0xFE    

	//  return: 0 - FALSE (no communication or no XStreamPro-Iso), 1 - TRUE


#ifndef __GNUC__
#ifdef  MSWIN_API
  MSPPRG_API BOOL   __stdcall 	DllMain(HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved);
#endif  //MSWIN_API
  MSPPRG_API INT_X	 __stdcall	VB_Trace_File( char *FileName, bool append = false );
  MSPPRG_API void   __stdcall  VB_Trace_Comment(char *comment);
  MSPPRG_API void   __stdcall	VB_Trace_ON( void );
  MSPPRG_API void	 __stdcall	VB_Trace_OFF( void );
  MSPPRG_API INT_X  __stdcall	VB_CloseInstances( void );
  MSPPRG_API INT_X  __stdcall	VB_OpenInstancesAndFPAs( char * FileName );
  MSPPRG_API INT_X  __stdcall	VB_Set_FPA_index( BYTE fpa );
  MSPPRG_API BYTE	 __stdcall	VB_Get_FPA_index( void );
  MSPPRG_API INT_X  __stdcall	VB_Check_FPA_index( void );
  MSPPRG_API INT_X  __stdcall	VB_LastStatus( BYTE fpa );
  MSPPRG_API INT_X  __stdcall	VB_DLLTypeVer( void );
  MSPPRG_API INT_X  __stdcall	VB_Multi_DLLTypeVer( void );
  MSPPRG_API INT_X  __stdcall	VB_Get_FPA_SN( BYTE );
  MSPPRG_API INT_X  __stdcall	VB_Get_FPA_Label( BYTE fpa, BYTE * label );
  MSPPRG_API INT_X  __stdcall	VB_Initialization( void );
  MSPPRG_API INT_X  __stdcall	VB_Get_Device_Info( INT_X index );
  MSPPRG_API INT_X  __stdcall	VB_Reset_Target( void );
  MSPPRG_API INT_X  __stdcall	VB_ReadCodeFile( char * FileName );
  MSPPRG_API INT_X	 __stdcall	VB_AppendCodeFile( char * FileName );
  MSPPRG_API INT_X  __stdcall	VB_ConfigFileLoad( char * Filename );
  MSPPRG_API INT_X  __stdcall  VB_Set_MCU_Name( char * MCU_name );
  MSPPRG_API void   __stdcall  VB_Reset_Config();
  MSPPRG_API BYTE   __stdcall	VB_GetReportMessageChar( INT_X index );
  MSPPRG_API INT_X  __stdcall	VB_Clr_Code_Buffer( void );
  MSPPRG_API INT_X	 __stdcall	VB_Put_Byte_to_Code_Buffer( INT_X addr, BYTE data );
  MSPPRG_API INT_X	 __stdcall	VB_Get_Byte_from_Code_Buffer( INT_X addr );
  MSPPRG_API INT_X	 __stdcall	VB_Put_Byte_to_Buffer( INT_X addr, BYTE data );
  MSPPRG_API INT_X	 __stdcall	VB_Get_Byte_from_Buffer( INT_X addr );
  MSPPRG_API INT_X  __stdcall	VB_AutoProgram( INT_X mode );
  MSPPRG_API INT_X  __stdcall	VB_Verify_Access_to_MCU( void );
  MSPPRG_API INT_X  __stdcall	VB_Memory_Erase( INT_X mode );
  MSPPRG_API INT_X  __stdcall	VB_Memory_Blank_Check( void );
  MSPPRG_API INT_X  __stdcall	VB_Memory_Write( INT_X mode );
  MSPPRG_API INT_X  __stdcall	VB_Memory_Verify( INT_X mode );
  MSPPRG_API INT_X	 __stdcall	VB_Memory_Read( void );
  MSPPRG_API INT_X	 __stdcall	VB_Lock_MCU( void );
  MSPPRG_API INT_X	 __stdcall	VB_Clear_Locked_Device( void );
  MSPPRG_API INT_X	 __stdcall	VB_Open_Target_Device( void );
  MSPPRG_API INT_X  __stdcall	VB_Close_Target_Device( void );
  MSPPRG_API INT_X  __stdcall	VB_Segment_Erase( INT_X  address );
  MSPPRG_API INT_X  __stdcall	VB_Sectors_Blank_Check( INT_X  start_addr, INT_X  stop_addr );
  MSPPRG_API INT_X  __stdcall	VB_Copy_Buffer_to_Flash( INT_X  start_addr, INT_X  size );
  MSPPRG_API INT_X  __stdcall	VB_Copy_Flash_to_Buffer( INT_X  start_addr, INT_X  size );
  MSPPRG_API INT_X	 __stdcall	VB_Write_Locking_Registers( void );
  MSPPRG_API INT_X	 __stdcall	VB_Write_Debug_Register( void );
  MSPPRG_API INT_X  __stdcall      VB_Write_Byte_to_RAM( INT_X  addr, BYTE data );
  MSPPRG_API INT_X  __stdcall      VB_Write_Word16_to_RAM( INT_X  addr, INT_X data );
  MSPPRG_API INT_X  __stdcall      VB_Write_Word32_to_RAM( INT_X  addr, INT_X data );
  MSPPRG_API INT_X	 __stdcall	VB_Read_Byte( INT_X addr );
  MSPPRG_API INT_X	 __stdcall	VB_Read_Word16( INT_X addr );
  MSPPRG_API INT_X	 __stdcall	VB_Read_Word32( INT_X addr );
  MSPPRG_API INT_X	 __stdcall	VB_Set_MCU_Family_Group( INT_X type, INT_X index );
  MSPPRG_API INT_X	 __stdcall	VB_Set_PC_and_RUN( INT_X PC_addr );
  MSPPRG_API INT_X  __stdcall	VB_Get_MCU_Data( INT_X  type );
  MSPPRG_API INT_X  __stdcall	VB_Get_Targets_Vcc( void );
  MSPPRG_API void	 __stdcall	VB_Disable_FPA_index( BYTE fpa );
  MSPPRG_API void	 __stdcall	VB_Enable_FPA_index( BYTE fpa );
  MSPPRG_API INT_X  __stdcall	VB_Power_Target( INT_X OnOff );
  MSPPRG_API INT_X	 __stdcall	VB_Set_fpa_IO( BYTE jtag, BYTE jtag_reset, BYTE EMU0, BYTE EMU1 );
  MSPPRG_API INT_X  __stdcall	VB_Get_CodeCS( INT_X dest );
  MSPPRG_API INT_X	 __stdcall	VB_Get_Sector_Size( INT_X address );
  MSPPRG_API INT_X	 __stdcall	VB_Use_Config_INI( BYTE use );
  MSPPRG_API INT_X  __stdcall  VB_Capture_PC_Addr();
  MSPPRG_API INT_X  __stdcall  VB_Synch_CPU_JTAG();
  MSPPRG_API INT_X	 __stdcall	VB_GetProgressBar( BYTE fpa );
  MSPPRG_API INT_X  __stdcall	VB_GetLastOpCode( BYTE fpa );  
  MSPPRG_API INT_X  __stdcall	VB_CancelAction();
  MSPPRG_API INT_X	 __stdcall	VB_Set_fpa_io_state( BYTE jtag, BYTE reset, BYTE VccOn );
  MSPPRG_API INT_X	 __stdcall  VB_Get_Power_Results(double *xs_adc);
  MSPPRG_API INT_X  __stdcall  VB_Write_Bytes_Block_to_RAM( INT_X start_addr, INT_X size, BYTE *data );
  MSPPRG_API BYTE_PTR __stdcall VB_Get_MCU_Name_list( INT_X type, INT_X index );
  MSPPRG_API BYTE_PTR __stdcall VB_Get_Config_Name_List(INT_X index);
  MSPPRG_API unsigned int __stdcall VB_Get_Config_Value_By_Name(char *name, INT_X type);
  MSPPRG_API INT_X	 __stdcall	VB_Set_Config_Value_By_Name(char *name, unsigned int newValue);
#endif //__GNUC__
}

#endif //FLASHPRO_DLL_H
